/* gfClient - A client for the genomic finding program that produces a .psl file. */
#include "common.h"
#include "linefile.h"
#include "fa.h"
#include "genoFind.h"

void gfClient(char *hostName, char *portName, char *nibDir, char *inName, char *outName)
/* gfClient - A client for the genomic finding program that produces a .psl file. */
{
struct lineFile *lf = lineFileOpen(inName, TRUE);
static struct dnaSeq seq;
struct ssBundle *bundleList;
enum ffStringency stringency = ffCdna;
FILE *out = mustOpen(outName, "w");

while (faSpeedReadNext(lf, &seq.dna, &seq.size, &seq.name))
    {
    printf("Processing %s\n", seq.name);
    gfAlignStrand(hostName, portName, nibDir, &seq, FALSE, stringency, 40, gfSavePsl, out);
    reverseComplement(seq.dna, seq.size);
    gfAlignStrand(hostName, portName, nibDir, &seq, TRUE,  stringency, 40, gfSavePsl, out);
    }
printf("Output is in %s\n", outName);
}

void usage()
/* Explain usage and exit. */
{
errAbort(
  "gfClient - A client for the genomic finding program that produces a .psl file\n"
  "usage:\n"
  "   gfClient host port nibDir in.fa out.psl\n");
}

int main(int argc, char *argv[])
/* Process command line. */
{
if (argc != 6)
    usage();
gfClient(argv[1], argv[2], argv[3], argv[4], argv[5]);
return 0;
}
